@@ -12,7 +12,7 @@
 /*                                                                            */
 /******************************************************************************/
 
-#if INCLUDE_5701_AX_FIX
+#ifdef INCLUDE_5701_AX_FIX
 
 #include "mm.h"
 #include "5701rls.h"
