@@ -633,10 +633,7 @@ b57_test_loopback(UM_DEVICE_BLOCK *pUmDevice, int testtype, int linespeed)
 	if (!pUmDevice->opened)
 		return ret;
 	LM_ResetAdapter(pDevice);
-	LM_HaltCpu(pDevice,T3_RX_CPU_ID);
-        if (!T3_ASIC_IS_5705_BEYOND(pDevice->ChipRevId)){
-		LM_HaltCpu(pDevice,T3_TX_CPU_ID);
-	}
+	LM_HaltCpu(pDevice,T3_RX_CPU_ID | T3_TX_CPU_ID);
 	switch (testtype) {
 		case NICE_LOOPBACK_TESTTYPE_MAC:
 			LM_EnableMacLoopBack(pDevice);
