@@ -280,7 +280,7 @@ bcm5700_read_pfs(char *page, char **start, off_t off, int count,
 			MM_GETSTATS(pStats->ifHCInMulticastPkts) +
 			MM_GETSTATS(pStats->ifHCInBroadcastPkts)));
 #if T3_JUMBO_RCV_RCB_ENTRY_COUNT
-	if (dev->mtu > 1500) {
+	if ((dev->mtu > 1500) && !T3_ASIC_IS_5705_BEYOND(pDevice->ChipRevId)) {
 		len += sprintf(page+len, "Rx_Jumbo_Packets\t\t%lu\n", 
 			((pStats == 0) ? 0 :
 			MM_GETSTATS(
