@@ -452,6 +452,7 @@ LM_STATUS MM_InitializeUmPackets(PLM_DEVICE_BLOCK pDevice);
 LM_STATUS MM_FreeRxBuffer(PLM_DEVICE_BLOCK pDevice, PLM_PACKET pPacket);
 LM_STATUS MM_CoalesceTxBuffer(PLM_DEVICE_BLOCK pDevice, PLM_PACKET pPacket);
 PLM_DEVICE_BLOCK MM_FindPeerDev(PLM_DEVICE_BLOCK pDevice);
+int MM_FindCapability(PLM_DEVICE_BLOCK pDevice, int capability);
 LM_VOID MM_UnmapRxDma(PLM_DEVICE_BLOCK pDevice, PLM_PACKET pPacket);
 #ifdef BCM_NAPI_RXPOLL
 LM_STATUS MM_ScheduleRxPoll(PLM_DEVICE_BLOCK pDevice);
@@ -459,7 +460,7 @@ LM_STATUS MM_ScheduleRxPoll(PLM_DEVICE_BLOCK pDevice);
 LM_STATUS MM_Sleep(PLM_DEVICE_BLOCK pDevice, LM_UINT32 msec);
 LM_STATUS LM_MbufWorkAround(PLM_DEVICE_BLOCK pDevice);
 
-#if INCLUDE_5703_A0_FIX
+#ifdef INCLUDE_5703_A0_FIX
 LM_STATUS LM_Load5703DmaWFirmware(PLM_DEVICE_BLOCK pDevice);
 #endif
 
