@@ -14,9 +14,11 @@
 #define MM_H
 
 #include <linux/config.h>
+
 #if defined(CONFIG_SMP) && ! defined(__SMP__)
 #define __SMP__
 #endif
+
 #if defined(CONFIG_MODVERSIONS) && defined(MODULE) && ! defined(MODVERSIONS)
 #ifndef BCM_SMALL_DRV
 #define MODVERSIONS
@@ -50,6 +52,7 @@
 #define MODULE_DEVICE_TABLE(pci, pci_tbl)
 #endif
 
+
 #include <linux/kernel.h>
 #include <linux/sched.h>
 #include <linux/string.h>
@@ -94,6 +97,14 @@
 #include <net/checksum.h>
 #endif
 
+#ifndef LINUX_KERNEL_VERSION
+#define LINUX_KERNEL_VERSION	0
+#endif
+
+#ifndef MAX_SKB_FRAGS
+#define MAX_SKB_FRAGS	0
+#endif
+
 #if (LINUX_VERSION_CODE >= 0x020400)
 #ifndef ETHTOOL_GEEPROM
 
