@@ -14,7 +14,7 @@
 
 #include "mm.h"
 
-#if INCLUDE_TCP_SEG_SUPPORT
+#ifdef INCLUDE_TCP_SEG_SUPPORT
 #include "fw_stkoffld.h"
 #include "fw_lso05.h"
 
